<?php

namespace AldiHelpers;

use PDO;

class AuxDB {

	// Constants defined in wp-config
	const USERNAME = DB_AUX_USER;
	const PASSWORD = DB_AUX_PASSWORD;
	const HOST = DB_AUX_HOST;
	const DB = DB_AUX_NAME;

	protected $connection;

	public function __construct() {
		$this->connection = $this->createConnection();
	}

	private function createConnection() {
		$username   = self::USERNAME;
		$password   = self::PASSWORD;
		$host       = self::HOST;
		$db         = self::DB;
		$connection = new PDO( "mysql:dbname=$db;host=$host;charset=utf8", $username, $password );

		return $connection;
	}

	public function getConnection() {
		return $this->connection;
	}

	public function execute( $query, $params = [] ) {

		$statement = $this->getConnection()->prepare( $query );

		foreach ( $params as $key => $value ) {
			$statement->bindParam( ':' . $key, $params[ $key ] );
		}
		$result = $statement->execute();

		if ( $result ) {
			return $statement;
		} else {
			return $result;
		}
	}

	public function select( $query, $params = [] ) {
		$statement = $this->execute( $query, $params );
		if ( $statement ) {
			$rows = $statement->fetchAll( PDO::FETCH_ASSOC );

			return $rows;
		} else {
			return false;
		}

	}

	public function insert( $query, $params = [] ) {
		$statement = $this->execute( $query, $params );

		return $statement;
	}

	public function lastInsertId() {
		return $this->getConnection()->lastInsertId();
	}

	public function update( $query, $params = [] ) {
		$statement = $this->execute( $query, $params );

		return $statement;
	}

}