<?php

if ( ! function_exists( 'dd' ) ) {

	function dd( $var ) {
		dump( $var );
		exit();
	}
}

if ( ! function_exists( 'remove_accents' ) ) {

	function remove_accents( $text ) {
		$text   = htmlentities( $text, ENT_QUOTES, 'UTF-8' );
		$text   = strtolower( $text );
		$patron = array(
			// Espacios, puntos y comas por guion
			//'/[\., ]+/' => ' ',

			// Vocales
			'/\+/'       => '',
			'/&agrave;/' => 'a',
			'/&egrave;/' => 'e',
			'/&igrave;/' => 'i',
			'/&ograve;/' => 'o',
			'/&ugrave;/' => 'u',

			'/&aacute;/' => 'a',
			'/&eacute;/' => 'e',
			'/&iacute;/' => 'i',
			'/&oacute;/' => 'o',
			'/&uacute;/' => 'u',

			'/&acirc;/' => 'a',
			'/&ecirc;/' => 'e',
			'/&icirc;/' => 'i',
			'/&ocirc;/' => 'o',
			'/&ucirc;/' => 'u',

			'/&atilde;/' => 'a',
			'/&etilde;/' => 'e',
			'/&itilde;/' => 'i',
			'/&otilde;/' => 'o',
			'/&utilde;/' => 'u',

			'/&auml;/' => 'a',
			'/&euml;/' => 'e',
			'/&iuml;/' => 'i',
			'/&ouml;/' => 'o',
			'/&uuml;/' => 'u',

			'/&auml;/'  => 'a',
			'/&euml;/'  => 'e',
			'/&iuml;/'  => 'i',
			'/&ouml;/'  => 'o',
			'/&uuml;/'  => 'u',

			// Otras letras y caracteres especiales
			'/&aring;/' => 'a',
//			'/&ntilde;/' => 'n',


		);

		$text = preg_replace( array_keys( $patron ), array_values( $patron ), $text );

		return $text;
	}
}

if ( ! function_exists( 'is_device' ) ) {
	function is_device( $devices ) {

		preg_match( "/" . implode( '|', $devices ) . "/", $_SERVER['HTTP_USER_AGENT'], $matches );

		return count( $matches ) > 0;
	}
}

if ( ! function_exists( 'is_device_ios' ) ) {
	function is_device_ios() {
		return is_device( [ 'iPod', 'iPhone', 'iPad' ] );
	}
}

if ( ! function_exists( 'is_device_android' ) ) {
	function is_device_android() {
		return is_device( [ 'Android' ] );
	}
}

if ( ! function_exists( 'is_device_smartphone' ) ) {
	function is_device_smartphone() {
		return is_device_ios() || is_device_android();
	}
}

if ( ! function_exists( 'is_browser_chrome' ) ) {
	function is_browser_chrome() {
		return is_device( [ 'Chrome' ] );
	}
}

if ( ! function_exists( 'is_browser_firefox' ) ) {
	function is_browser_firefox() {
		return is_device( [ 'Firefox' ] );
	}
}

if ( ! function_exists( 'html_classes' ) ) {
	/**
	 * Builds an HTML class attribute dynamically
	 * Usage:
	 * {!! html_classes(['home' => true, 'main', 'dont-use-this' => false]) !!}
	 * Returns:
	 *  class="home main".
	 *
	 * @param array $classes
	 *
	 * @return string
	 */
	function html_classes( array $classes ) {
		$html = '';
		foreach ( $classes as $name => $bool ) {
			if ( is_int( $name ) ) {
				$name = $bool;
				$bool = true;
			}
			if ( $bool ) {
				$html .= $name . ' ';
			}
		}
		if ( ! empty( $html ) ) {
			return ' class="' . trim( $html ) . '"';
		}

		return '';
	}
}